<?php
/*
  Plugin Name: DZS Scroller
  Plugin URI: http://digitalzoomstudio.net/
  Description: Creates scrollbars for your content.
  Version: 4.00
  Author: Digital Zoom Studio
  Author URI: http://digitalzoomstudio.net/
 */
require_once('dzs_functions.php');
require_once('noerror.php');
$dzsscr = new DZSScroller();

class DZSScroller {

    public $main_options = '';
    public $thepath;
    public $indexnr = 0;
    public $shortcode = 'scroller';
    public $alwaysembed = 'on';
    public $mode = 'plugin';

    const SHORTCODE = 'scroller';

    function __construct() {
        if ($this->mode == 'plugin') {
            //echo plugins_url('', __FILE__);
            $this->thepath = plugins_url('', __FILE__) . '/';
        } else {
            $this->thepath = THEME_URL . 'plugins/dzs-scroller/';
        }

        add_action('wp_print_styles', array($this, 'fe_embedscripts'));
        add_shortcode($this->shortcode, array($this, 'show_shortcode'));
        add_shortcode('dzs_' . $this->shortcode, array($this, 'show_shortcode'));
        add_shortcode($this->shortcode . '_gallery', array($this, 'show_post_gallery'));
        add_shortcode($this->shortcode . '_body', array($this, 'shortcode_body'));


        add_action('add_meta_boxes', array($this, 'handle_add_meta_boxes'));

        add_action('init', array($this, 'handle_init'));
        add_action('admin_head', array($this, 'handle_admin_head'));
        add_action('save_post', array($this, 'admin_meta_save'));

        add_action('wp_ajax_dzsscr_preparePreview', array($this, 'ajax_preparePreview'));
    }

    function handle_init() {
        wp_enqueue_script('jquery');
        if (is_admin()) {
            if (current_user_can('edit_posts') || current_user_can('edit_pages')) {
                wp_enqueue_script('dzsscr.admin', $this->thepath . 'admin/admin.js');
                wp_enqueue_style('dzsscr.admin', $this->thepath . 'admin/admin.css');
                wp_enqueue_script('thickbox');
                wp_enqueue_style('thickbox');
                wp_enqueue_script('jquery-ui-core');
                wp_enqueue_script('jquery-ui-sortable');
                wp_enqueue_script('jquery-ui-droppable');
                wp_enqueue_style('dzs.zoombox', $this->thepath . 'zoombox/zoombox.css');
                wp_enqueue_script('dzs.zoombox', $this->thepath . 'zoombox/zoombox.js');
                wp_enqueue_script('dzsscr_htmleditor_plugin', $this->thepath . 'tinymce/plugin-htmleditor.js');
                //add_filter("mce_external_plugins" , array($this, 'tinymce_plugin'));
                //add_filter("mce_buttons" , array($this, 'tinymce_register_button'));
            }
        }
    }

    function handle_add_meta_boxes() {

        add_meta_box('dzsscr_meta_gallery', __('Scroller Gallery', 'dzsscr'), array($this, 'admin_meta_gallery'), 'page', 'side');
        add_meta_box('dzsscr_meta_gallery', __('Scroller Gallery', 'dzsscr'), array($this, 'admin_meta_gallery'), 'post', 'side');
    }

    function admin_meta_gallery() {
        global $post;
        ?>
        <div id="product_images_container">
            <ul class="dzsscr_item_gallery_list">
                <?php
                if (metadata_exists('post', $post->ID, 'dzsscr_image_gallery')) {
                    $product_image_gallery = get_post_meta($post->ID, 'dzsscr_image_gallery', true);
                }

                $attachments = array_filter(explode(',', $product_image_gallery));

                if ($attachments) {
                    foreach ($attachments as $attachment_id) {
                        echo '<li class="item-element" data-id="' . $attachment_id . '">
' . wp_get_attachment_image($attachment_id, 'thumbnail') . '
<div class="ui-delete"></div>
</li>';
                    }
                }
                ?>
            </ul>

            <input type="hidden" id="dzsscr_image_gallery" name="dzsscr_image_gallery" value="<?php echo esc_attr($product_image_gallery); ?>" />
            <button class="button-secondary dzsscr-add-gallery-item"><?php echo __('Add Media', 'dzsscr'); ?></button>
        </div>
        <?php
    }

    function admin_meta_save($post_id) {
        global $post;
        if (!$post) {
            return;
        }
        /* Check autosave */
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return $post_id;
        }

        if (isset($_REQUEST['dzs_nonce'])) {
            $nonce = $_REQUEST['dzs_nonce'];
            if (!wp_verify_nonce($nonce, 'dzs_nonce'))
                wp_die('Security check');
        }
        if (is_array($_POST)) {
            $auxa = $_POST;
            foreach ($auxa as $label => $value) {

                if (strpos($label, 'dzsscr_') !== false) {
                    DZSHelpers::wp_savemeta($post->ID, $label, $value);
                }
            }
        }
    }

    function ajax_preparePreview() {
        echo do_shortcode($_POST['postdata']);
    }

    function handle_admin_head() {
        if (is_admin()) {
            echo '<script>
var dzsscr_settings = {
    thepath : "' . $this->thepath . '"
};window.init_zoombox(); </script>';
            wp_enqueue_script('dzsscr_configreceiver', $this->thepath . 'tinymce/receiver.js');
        }
    }

    function fe_embedscripts() {
        global $post;
        wp_enqueue_script('jquery');
        if (is_admin()) {
            return;
        }
        if ($this->alwaysembed != 'on' && $post) {
            $sw = false;
            if (dzs_find_string($post->post_content, '[' . $this->shortcode) || dzs_find_string($post->post_content, '[dzs_' . $this->shortcode)) {
                $sw = true;
            }
            if ($sw == false) {
                return;
            }
        }
        wp_enqueue_script('scroller', $this->thepath . 'dzsscroller/scroller.js');
        wp_enqueue_style('scroller', $this->thepath . 'dzsscroller/scroller.css');
    }

    function show_shortcode($atts, $content = null) {
        //[scroller]test teste test[/scroller]
        $fout = '';
        $w = '';
        $h = '';
        $iw = '';
        $ih = '';
        $type = 'simple';

        $margs = array(
            'width' => '',
            'height' => '',
            'type' => 'simple',
            'settings_skin' => 'skin_default',
            'responsive' => 'on',
            'donotparse' => 'off',
            'settings_multiplier' => '3',
            'settings_refresh' => '0',
        );
        if (is_array($atts) == false) {
            $atts = array();
        };

        $margs = array_merge($margs, $atts);

        if (isset($margs['type'])) {
            $type = $margs['type'];
        }

        //print_r($margs);
        if (isset($margs['width'])) {
            $w = $margs['width'];
        }
        if (isset($margs['height'])) {
            $h = $margs['height'];
        }


        $settings_skin = 'skin_default';
        if (isset($margs['settings_skin'])) {
            $settings_skin = $margs['settings_skin'];
            //echo 'ceva' .$settings_skin;
        }
        $settings_autoresizescrollbar = 'off';
        if (isset($margs['settings_autoresizescrollbar'])) {
            $settings_autoresizescrollbar = $margs['settings_autoresizescrollbar'];
        }
        $settings_scrollbar = 'on';
        if (isset($margs['settings_scrollbar'])) {
            $settings_scrollbar = $margs['settings_scrollbar'];
        }
        $settings_scrollbyhover = 'off';
        if (isset($margs['settings_scrollbyhover'])) {
            $settings_scrollbyhover = $margs['settings_scrollbyhover'];
        }
        $settings_autoheight = 'on';
        if (isset($margs['settings_autoheight'])) {
            $settings_autoheight = $margs['settings_autoheight'];
        }
        $settings_autoheight = 'on';
        if (isset($margs['settings_autoheight'])) {
            $settings_autoheight = $margs['settings_autoheight'];
        }
        $settings_multiplier = '3';
        if (isset($margs['settings_multiplier'])) {
            $settings_multiplier = $margs['settings_multiplier'];
        }
        $settings_scrollbar = 'on';
        if (isset($margs['settings_scrollbar'])) {
            $settings_scrollbar = $margs['settings_scrollbar'];
        }
        $settings_fadeoutonleave = 'off';
        if (isset($margs['settings_fadeoutonleave'])) {
            $settings_fadeoutonleave = $margs['settings_fadeoutonleave'];
        }
        $settings_replacewheelxwithy = 'off';
        if (isset($margs['settings_replacewheelxwithy'])) {
            $settings_replacewheelxwithy = $margs['settings_replacewheelxwithy'];
        }
        $settings_forcesameheight = 'off';
        if (isset($margs['settings_forcesameheight'])) {
            $settings_forcesameheight = $margs['settings_forcesameheight'];
        }

        if ($type == 'full-vertical') {
            $iw = 'auto';
            $ih = 'auto';
        }
        if ($type == 'simple') {
            $iw = 'auto';
            $ih = 'auto';
        }
        if ($type == 'full-horizontal') {
            $iw = 10000;
            $ih = $h;
            $settings_forcesameheight = 'on';
        }


        $settings_autoheight = 'off';

        if (isset($margs['settings_autoheight'])) {
            $settings_autoheight = $margs['settings_autoheight'];
        }

        if (isset($margs['iw'])) {
            $iw = $margs['iw'];
        }
        if (isset($margs['ih'])) {
            $ih = $margs['ih'];
        }


        $str_w = '';
        if ($w != '') {
            if (strpos($w, '%') !== false || $w == 'auto') {

                $str_w = ' width:' . $w . ';';
            } else {
                $str_w = ' width:' . $w . 'px;';
            }
        }

        $str_h = '';
        if ($h != '') {
            if (strpos($h, '%') !== false || $h == 'auto') {
                $str_h = ' height:' . $h . ';';
            } else {
                $str_h = ' height:' . $h . 'px;';
            }
        }
        //echo 'ceva'.$w.$h.$str_w.$str_h;

        $easingclass = '';
        if (isset($margs['settings_easing']) && $margs['settings_easing'] == 'on') {
            $easingclass = ' easing';
        }
        $fout.='<div id="scroller' . $this->indexnr . '" class="scroller-con' . $easingclass . '" style="' . $str_w . $str_h . '">
            <div class="inner" ';
        if ($iw != 'auto') {
            $siw = '';
            $sih = '';
            if ($iw != '') {
                $siw = 'width:' . $iw . 'px';
            }
            if ($ih != '') {
                $sih = '; height:' . $ih . 'px;';
            }
            $fout.='style="' . $siw . $sih . '"';
        }

        $fout.='>';
        if ($type == 'full-horizontal') {
            $fout.='<span class="real-inner">';
        }
        $da_content = do_shortcode(stripslashes($content));
        if ($margs['donotparse'] == 'on') {
            $da_content = stripslashes($content);
            return $content;
        }
        $fout.=$da_content;
        if ($type == 'full-horizontal') {
            $fout.='</span>';
        }
        $fout.='</div></div>
            ';
        $jqcall = 'jQuery(window).load(function(){';
        $pos = strpos($type, 'full');
        if ($pos === false) {
            $jqcall = 'jQuery(document).ready(function($){';
        }
        $fout.='<script>
' . $jqcall . '
jQuery("#scroller' . $this->indexnr . '").scroller({ 
settings_dragmethod : "drag"
, settings_skin : "' . $settings_skin . '"
, settings_autoheight : "' . $settings_autoheight . '"
, settings_autoresizescrollbar : "' . $settings_autoresizescrollbar . '"
, settings_forcesameheight : "' . $settings_forcesameheight . '"
, settings_fadeoutonleave : "' . $settings_fadeoutonleave . '"
, settings_scrollbyhover : "' . $settings_scrollbyhover . '"
, settings_replacewheelxwithy : "' . $settings_replacewheelxwithy . '"
,settings_multiplier:"' . $settings_multiplier . '"
,settings_refresh:"' . $margs['settings_refresh'] . '"
});
})
</script>';
        $this->indexnr++;
        return $fout;
    }

    public function show_post_gallery($atts) {
        global $post;

        $fout = '';


        $margs = array(
            'height' => 300,
            'type' => 'full-horizontal',
            'settings_autoheight' => 'on',
            'settings_easing' => 'on',
            'settings_forcesameheight' => 'on',
            'settings_skin' => 'skin_alternate',
            'settings_replacewheelxwithy' => 'on',
        );
        if (is_array($atts)) {
            $margs = array_merge($margs, $atts);
        }


        $the_id = $post->ID;

        $meta_image_gallery = get_post_meta($the_id, 'dzsscr_image_gallery', true);
        $meta_image_gallery_images = explode(',', $meta_image_gallery);

        //echo 'ceva'; print_r($meta_image_gallery);

        if ((is_array($meta_image_gallery_images) && count($meta_image_gallery_images) > 1) == false) {
            return;
        }


        $fout .= '<div class="scroller-gallery-con">';
        //print_r($post);
        $scontent = '';
        $imageheight = -1;


        if ((is_array($meta_image_gallery_images) && count($meta_image_gallery_images) > 1)) {
            foreach ($meta_image_gallery_images as $img) {

                $aux_po = get_post($img);
                $the_src = '';
                $the_thumb = '';
                if ($aux_po == false) {
                    continue;
                }
                if ($aux_po->post_mime_type == 'video/mp4') {
                    $the_src = $aux_po->guid;
                } else {
                    $imgsrc = wp_get_attachment_image_src($img, 'full');
                    $the_src = $imgsrc[0];
                    $the_thumb = $the_src;
                }

                if (get_post_meta($img, '_attachment_video_thumb', true) != '') {
                    $the_thumb = get_post_meta($img, '_attachment_video_thumb', true);
                }

                $scontent.= '<img src="' . $the_thumb . '" ';
                $scontent.= '/>';
            }
        }
        //echo $scontent;
        //print_r($pargs);
        $fout .= $this->show_shortcode($margs, $scontent);
        $fout .= '</div>';
        return $fout;
    }

    public function shortcode_body($atts) {
        $fout = '';

        $jqcall = 'jQuery(window).load(function(){';

        $fout.='<script>
' . $jqcall . '
jQuery("body").scroller({
		isbody : "on"
		, settings_skin:"skin_blackwhite"
	});
})
</script>';

        return $fout;
    }

}
?>